//
// The Open Toolkit Library License
//
// Copyright (c) 2006 - 2009 the Open Toolkit library.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
// the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//

using System;

namespace OpenTK
{

    /// <summary>
    /// This exception is thrown when a GraphicsContext property cannot be changed after creation.
    /// </summary>
    public class ContextExistsException : ApplicationException
    {
        /// <summary>
        /// Constructs a new ContextExistsException instance.
        /// </summary>
        /// <param name="message">A System.String explaining the cause of this exception.</param>
        public ContextExistsException(string message)
        {
            Message = message;
        }

        /// <summary>
        /// Gets a System.String explaining the cause of this exception.
        /// </summary>
        public override string Message { get; }
    }

    /// <summary>
    /// This exception is thown when a binding method is called and the bindings have not been rewritten by Rewrite.exe.
    /// </summary>
    public class BindingsNotRewrittenException : Exception
    {
        /// <summary>
        /// Constructs a new BindingsNotRewrittenException instance.
        /// </summary>
        public BindingsNotRewrittenException() : base("Rewrite.exe has not been run.") { }
    }
}